@@ -32,6 +32,7 @@ BIGQUERY_EMULATOR_HOST = os.environ.get('BIGQUERY_EMULATOR_HOST')
 if BIGQUERY_EMULATOR_HOST:
     API_ROOT = f'http://{BIGQUERY_EMULATOR_HOST}/bigquery/v2'
 
+
 class SourceFormat(Enum):
     AVRO = 'AVRO'
     CSV = 'CSV'
@@ -145,7 +146,9 @@ class Job:
 
     # https://cloud.google.com/bigquery/docs/reference/rest/v2/jobs/getQueryResults
     async def get_query_results(self, session: Optional[Session] = None,
-                                timeout: int = 60) -> Dict[str, Any]:
+                                timeout: int = 60,
+                                params: Optional[Dict[str, Any]] = None,
+                                ) -> Dict[str, Any]:
         """Get the specified jobQueryResults by job ID."""
 
         project = await self.project()
@@ -154,7 +157,8 @@ class Job:
         headers = await self.headers()
 
         s = AioSession(session) if session else self.session
-        resp = await s.get(url, headers=headers, timeout=timeout)
+        resp = await s.get(url, headers=headers, timeout=timeout,
+                           params=params or {})
         data: Dict[str, Any] = await resp.json()
         return data
 
@@ -196,6 +200,17 @@ class Job:
             self.job_id = response['jobReference']['jobId']
         return response
 
+    async def result(self,
+                     session: Optional[Session] = None) -> Dict[str, Any]:
+        data = await self.get_job(session)
+        status = data.get('status', {})
+        if status.get('state') == 'DONE':
+            if 'errorResult' in status:
+                raise Exception('Job finished with errors', status['errors'])
+            return data
+
+        raise OSError('Job results are still pending')
+
 
 class Table:
     def __init__(self, dataset_name: str, table_name: str,
@@ -281,12 +296,12 @@ class Table:
         return body
 
     def _make_load_body(
-            self, source_uris: List[str], project: str, autodetect: bool,
-            source_format: SourceFormat,
-            write_disposition: Disposition,
-            ignore_unknown_values: bool,
-            schema_update_options: List[SchemaUpdateOption]
-        ) -> Dict[str, Any]:
+        self, source_uris: List[str], project: str, autodetect: bool,
+        source_format: SourceFormat,
+        write_disposition: Disposition,
+        ignore_unknown_values: bool,
+        schema_update_options: List[SchemaUpdateOption]
+    ) -> Dict[str, Any]:
         return {
             'configuration': {
                 'load': {
@@ -440,14 +455,14 @@ class Table:
     # https://cloud.google.com/bigquery/docs/reference/rest/v2/jobs/insert
     # https://cloud.google.com/bigquery/docs/reference/rest/v2/Job#JobConfigurationLoad
     async def insert_via_load(
-            self, source_uris: List[str], session: Optional[Session] = None,
-            autodetect: bool = False,
-            source_format: SourceFormat = SourceFormat.CSV,
-            write_disposition: Disposition = Disposition.WRITE_TRUNCATE,
-            timeout: int = 60,
-            ignore_unknown_values: bool = False,
-            schema_update_options: Optional[List[SchemaUpdateOption]] = None
-        ) -> Job:
+        self, source_uris: List[str], session: Optional[Session] = None,
+        autodetect: bool = False,
+        source_format: SourceFormat = SourceFormat.CSV,
+        write_disposition: Disposition = Disposition.WRITE_TRUNCATE,
+        timeout: int = 60,
+        ignore_unknown_values: bool = False,
+        schema_update_options: Optional[List[SchemaUpdateOption]] = None
+    ) -> Job:
         """Loads entities from storage to BigQuery."""
         project = await self.project()
         url = f'{API_ROOT}/projects/{project}/jobs'
